﻿/*
 
 Attrice Corporation 2008-2009

 This source code and the compiled software are provided "AS IS", without warranty of any kind, express or implied, 
 including but not limited to the warranties of merchantability, fitness for a particular purpose 
 and noninfringement. In no event shall the authors or copyright holders be liable for any claim, 
 damages or other liability, whether in an action of contract, tort or otherwise, arising from, 
 out of or in connection with the software or the use or other dealings in the software. 

 Questions? Contact us at info@attrice.info
  
*/


using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

using Microsoft.StyleCop;

namespace Attrice.TeamFoundation.StyleCop
{
  public partial class DetailsForm : Form
  {
    public DetailsForm(Dictionary<string, List<ViolationEventArgs>> violations)
    {
      InitializeComponent();
      FillData(violations);
    }

    private void FillData(Dictionary<string, List<ViolationEventArgs>> violations)
    {
      List<ListViewItem> issueItems = new List<ListViewItem>();
      foreach (string project in violations.Keys)
      {
        //string projectName = Path.GetFileNameWithoutExtension(project);
        List<ViolationEventArgs> issues = violations[project];

        ListViewItem item = new ListViewItem(new string[] { project, issues.Count.ToString() });
        issueItems.Clear();
        foreach (ViolationEventArgs issue in issues)
        {
          string file = "N/A";
          if ((issue.SourceCode != null && issue.SourceCode.Path != null) && issue.SourceCode.Path.Length > 0)
            file = issue.SourceCode.Path;
          else if ((issue.Element != null && issue.Element.Document != null) && (issue.Element.Document.SourceCode != null && issue.Element.Document.SourceCode.Path != null))
            file = issue.Element.Document.SourceCode.Path;

          string message = issue.Violation.Rule.CheckId + ": " + issue.Message;

          ListViewItem issueItem = new ListViewItem(new string[] { message, file, issue.LineNumber.ToString() });
          issueItems.Add(issueItem);
        }
        item.Tag = issueItems.ToArray();
        listView1.Items.Add(item);
      }
    }

    private void button1_Click(object sender, EventArgs e)
    {
      Close();
    }

    private void listView1_SelectedIndexChanged(object sender, EventArgs e)
    {
      if (listView1.SelectedItems.Count != 1)
        return;
      ListViewItem item = listView1.SelectedItems[0];
      listView2.BeginUpdate();
      listView2.Items.Clear();
      listView2.Items.AddRange(item.Tag as ListViewItem[]);
      listView2.EndUpdate();
    }
  }
}
